"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const strings_1 = require("./utils/strings");
const interfaces_1 = require("../interfaces");
const number_1 = require("./utils/number");
const hash_1 = require("./utils/hash");
const dates_1 = require("./utils/dates");
const objects_1 = require("./utils/helpers/objects");
class SearchEngine {
    constructor(collection) {
        this.shouldHave = [];
        this.mustHave = [];
        this.initialData = [];
        const collectionToBeStored = collection.map((item) => (Object.assign({ fs_uuid: (0, hash_1.hashCode)(JSON.stringify(item)) }, item)));
        this.initialData = collectionToBeStored;
        this.mustHave = collectionToBeStored;
    }
    search(queries) {
        const query = {
            '@or': queries.filter((item) => item.operator === interfaces_1.RuleOperator.OR),
            '@and': queries.filter((item) => item.operator === interfaces_1.RuleOperator.AND),
        };
        this.processShouldArraySearch(query[interfaces_1.RuleOperator.OR]);
        this.processMustArraySearch(query[interfaces_1.RuleOperator.AND]);
        return this.all;
    }
    processShouldArraySearch(queryArray) {
        this.shouldHave = this.initialData.filter((data) => this.filterData(data, queryArray));
    }
    processMustArraySearch(queryArray) {
        this.mustHave = this.mustHave.filter((data) => this.filterMustArrayData(data, queryArray));
    }
    filterData(data, queryArray) {
        return queryArray.some((queryCurrent) => {
            return this.someDataIsValid(queryCurrent, data);
        });
    }
    filterMustArrayData(data, queryArray) {
        const checkedsRoles = queryArray.map((queryCurrent) => {
            return this.someDataIsValid(queryCurrent, data);
        });
        return !checkedsRoles.some((item) => item === false);
    }
    someDataIsValid(queryCurrent, data) {
        const field = queryCurrent.field || '';
        switch (queryCurrent.type) {
            case 'string':
                return new strings_1.StringProcessor((queryCurrent === null || queryCurrent === void 0 ? void 0 : queryCurrent.term) || null, queryCurrent.role).compareWith(data[field], queryCurrent.caseSensitive || false);
            case 'number':
                return new number_1.NumberProcessor((queryCurrent === null || queryCurrent === void 0 ? void 0 : queryCurrent.term) || null, queryCurrent.role).compareWith(data[field]);
            case 'date':
                return new dates_1.DateProcessor((queryCurrent === null || queryCurrent === void 0 ? void 0 : queryCurrent.term) || null, queryCurrent.role).compareWith(data[field]);
            case 'custom':
                if (queryCurrent.filter && typeof queryCurrent.filter === 'function') {
                    const datum = (0, objects_1.omit)(data, ['fs_uuid']);
                    return queryCurrent.filter(datum);
                }
                throw new Error('[flexysearch]: Custom filter not valid');
            default:
                throw new Error('[flexysearch]: Processor not found');
        }
    }
    get all() {
        const data = this.mustHave.concat(this.shouldHave);
        return (data
            .filter((char, index) => {
            return data.indexOf(char) === index;
        })
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            .map((_a) => {
            var { fs_uuid } = _a, rest = tslib_1.__rest(_a, ["fs_uuid"]);
            return rest;
        }));
    }
}
exports.default = SearchEngine;
tslib_1.__exportStar(require("../interfaces"), exports);
//# sourceMappingURL=index.js.map