"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateProcessor = void 0;
const index_1 = require("../../interfaces/index");
const regexp_1 = require("./helpers/regexp");
class DateProcessor {
    constructor(value, role) {
        this.term = value;
        this.role = role;
    }
    checkIsValid(valueToBeCompared) {
        return !!String(valueToBeCompared).match(regexp_1.VALIDATE_DATE_REGEXP);
    }
    checkisEmpty(valueToBeCompared) {
        return !this.checkIsValid(valueToBeCompared);
    }
    checkIsEqualDate(valueToBeCompared) {
        if (!this.checkIsValid(valueToBeCompared) || !this.checkIsValid(this.term)) {
            return false;
        }
        const date = new Date(valueToBeCompared);
        const dateTerm = new Date(this.term);
        const date1 = [date.getDate(), date.getMonth(), date.getFullYear()].join('');
        const date2 = [dateTerm.getDate(), dateTerm.getMonth(), dateTerm.getFullYear()].join('');
        return date1 === date2;
    }
    checkIsNotEqualDate(valueToBeCompared) {
        if (!this.checkIsValid(valueToBeCompared) || !this.checkIsValid(this.term)) {
            return true;
        }
        const date = new Date(valueToBeCompared);
        const dateTerm = new Date(this.term);
        const date1 = [date.getDate(), date.getMonth(), date.getFullYear()].join('');
        const date2 = [dateTerm.getDate(), dateTerm.getMonth(), dateTerm.getFullYear()].join('');
        return date1 !== date2;
    }
    isAfterOrBefore(valueToBeCompared, isBefore = false, includeOn = false) {
        if (!this.checkIsValid(valueToBeCompared) || !this.checkIsValid(this.term)) {
            return false;
        }
        const date = new Date(valueToBeCompared).getTime();
        const dateTerm = new Date(this.term).getTime();
        if (includeOn) {
            return isBefore ? dateTerm >= date : dateTerm <= date;
        }
        return isBefore ? dateTerm > date : dateTerm < date;
    }
    isBetween(valueToBeCompared) {
        if ((this.term || []).length !== 2) {
            return false;
        }
        const isInvalidStart = !this.checkIsValid(this.term[0]);
        const isInvalidEnd = !this.checkIsValid(this.term[1]);
        if (isInvalidStart || isInvalidEnd || !this.checkIsValid(valueToBeCompared)) {
            return false;
        }
        const dateStart = new Date(this.term[0]).getTime();
        const dateEnd = new Date(this.term[1]).getTime();
        const dateTerm = new Date(valueToBeCompared).getTime();
        return dateTerm >= dateStart && dateTerm <= dateEnd;
    }
    compareWith(valueToBeCompared) {
        switch (this.role) {
            case index_1.RuleDateOptions.equals:
                return this.checkIsEqualDate(valueToBeCompared);
            case index_1.RuleDateOptions.isNotEquals:
                return this.checkIsNotEqualDate(valueToBeCompared);
            case index_1.RuleDateOptions.isNotEmpty:
                return !this.checkisEmpty(valueToBeCompared);
            case index_1.RuleDateOptions.empty:
                return this.checkisEmpty(valueToBeCompared);
            case index_1.RuleDateOptions.isAfter:
                return this.isAfterOrBefore(valueToBeCompared);
            case index_1.RuleDateOptions.isOnOrAfter:
                return this.isAfterOrBefore(valueToBeCompared, false, true);
            case index_1.RuleDateOptions.isBefore:
                return this.isAfterOrBefore(valueToBeCompared, true);
            case index_1.RuleDateOptions.isOnOrBefore:
                return this.isAfterOrBefore(valueToBeCompared, true, true);
            case index_1.RuleDateOptions.isBetween:
                return this.isBetween(valueToBeCompared);
            default:
                throw new Error('[flexysearch]: Invalid role in Dates');
        }
    }
}
exports.DateProcessor = DateProcessor;
//# sourceMappingURL=dates.js.map