"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberProcessor = void 0;
const index_1 = require("../../interfaces/index");
class NumberProcessor {
    constructor(value, role) {
        this.term = Number(value);
        this.role = role;
    }
    getRegexValue(value) {
        return new RegExp(value, 'gi');
    }
    checkContains(valueToBeCompared) {
        const regexpMatches = (String(valueToBeCompared).match(this.getRegexValue(String(this.term))) || []).length;
        if (this.role === index_1.RuleNumberOptions.notContains) {
            return regexpMatches === 0;
        }
        return regexpMatches > 0;
    }
    checkisEmpty(numberValue, valueToBeCompared) {
        if (!valueToBeCompared || valueToBeCompared === null) {
            return true;
        }
        return !Number.isSafeInteger(numberValue);
    }
    compareWith(valueToBeCompared) {
        const numberValue = Number(valueToBeCompared);
        switch (this.role) {
            case index_1.RuleNumberOptions.equals:
                return numberValue === this.term;
            case index_1.RuleNumberOptions.isNotEquals:
                return numberValue !== this.term;
            case index_1.RuleNumberOptions.biggerThan:
                return numberValue > this.term && !!valueToBeCompared;
            case index_1.RuleNumberOptions.biggerOrEquals:
                return numberValue >= this.term && !!valueToBeCompared;
            case index_1.RuleNumberOptions.smallerThan:
                return numberValue < this.term && !!valueToBeCompared;
            case index_1.RuleNumberOptions.smallerOrEquals:
                return numberValue <= this.term && !!valueToBeCompared;
            case index_1.RuleNumberOptions.contains:
            case index_1.RuleNumberOptions.notContains:
                return this.checkContains(valueToBeCompared);
            case index_1.RuleNumberOptions.isEmpty:
                return this.checkisEmpty(numberValue, valueToBeCompared);
            case index_1.RuleNumberOptions.isNotEmpty:
                return !this.checkisEmpty(numberValue, valueToBeCompared);
            default:
                throw new Error('[flexysearch]: Invalid role in Numbers');
        }
    }
}
exports.NumberProcessor = NumberProcessor;
//# sourceMappingURL=number.js.map