"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringProcessor = void 0;
const interfaces_1 = require("../../interfaces");
class StringProcessor {
    constructor(value, role) {
        this.term = '';
        this.caseSensitive = false;
        this.term = value;
        this.role = role;
    }
    getRegexValue(value) {
        const flags = this.caseSensitive ? 'g' : 'gi';
        return new RegExp(value, flags);
    }
    checkContains(valueToBeCompared) {
        const term = this.getRegexValue(String(this.term));
        const regexpMatches = (valueToBeCompared.match(term) || []).length;
        if (this.role === interfaces_1.RuleStringOptions.notContains) {
            return regexpMatches === 0;
        }
        return regexpMatches > 0;
    }
    checkEquals(valueToBeCompared) {
        if (!this.caseSensitive) {
            return valueToBeCompared.toLowerCase() === this.term.toLowerCase();
        }
        return valueToBeCompared === this.term;
    }
    checkisEmpty(valueToBeCompared) {
        return !valueToBeCompared;
    }
    startsWithTerm(valueToBeCompared) {
        if (!this.caseSensitive) {
            return valueToBeCompared.toLowerCase().startsWith(this.term.toLowerCase());
        }
        return valueToBeCompared.startsWith(this.term);
    }
    endsWithTerm(valueToBeCompared) {
        if (!this.caseSensitive) {
            return valueToBeCompared.toLowerCase().endsWith(this.term.toLowerCase());
        }
        return valueToBeCompared.endsWith(this.term);
    }
    compareWith(valueToBeCompared, caseSensitive) {
        this.caseSensitive = caseSensitive;
        if (typeof valueToBeCompared !== 'string') {
            return false;
        }
        switch (this.role) {
            case interfaces_1.RuleStringOptions.equals:
                return this.checkEquals(valueToBeCompared);
            case interfaces_1.RuleStringOptions.contains:
            case interfaces_1.RuleStringOptions.notContains:
                return this.checkContains(valueToBeCompared);
            case interfaces_1.RuleStringOptions.isEmpty:
                return this.checkisEmpty(valueToBeCompared);
            case interfaces_1.RuleStringOptions.isNotEmpty:
                return !this.checkisEmpty(valueToBeCompared);
            case interfaces_1.RuleStringOptions.startsWith:
                return this.startsWithTerm(valueToBeCompared);
            case interfaces_1.RuleStringOptions.endsWith:
                return this.endsWithTerm(valueToBeCompared);
            default:
                throw new Error('[flexysearch]: Invalid role in String');
        }
    }
}
exports.StringProcessor = StringProcessor;
//# sourceMappingURL=strings.js.map